@@ -37,7 +37,7 @@ def generate_actions_from_irc_message(args,printer):
     if from_me:
         monitored_channels[channel] = time.time()
         if debug:
-            printer("Now monitoring channel: " + channel, str(monitored_channels[channel])
+            printer("Now monitoring channel: " + channel, str(monitored_channels[channel]))
 
     monitoring_channel = monitored_channel( channel, monitored_channels )
     if not to_me and not from_me and channel == "test":
@@ -51,7 +51,7 @@ def generate_actions_from_irc_message(args,printer):
                                            u"alert_message": alrt_msg,
                                            u"urgency": u"low"}} )
         if debug:
-            printer("Monitoring Channel Msg" + channel, str(monitored_channels)
+            printer("Monitoring Channel Msg" + channel, str(monitored_channels))
                     
     return actions_todo
 
